% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/variogram.R
\name{variogram}
\alias{variogram}
\title{compute the variogram}
\usage{
variogram(
  path,
  simulation_id,
  response_var,
  factor_vars,
  response_reduce_fn = max,
  factor_reduce_fn,
  distance_fn = function(xa, xb) {
     abs(xa - xb)
 },
  max_to_take = 100
)
}
\arguments{
\item{path}{\code{character} where the simulations are to be found}

\item{simulation_id}{\code{character} the id of the simulation to read}

\item{response_var}{\code{character} the variable whose response we are studying}

\item{factor_vars}{\code{character} vector the factor names for which sensitivity will be estimated}

\item{response_reduce_fn}{\code{fn} the function to be used to reduce the response variable to one value (default=max)}

\item{factor_reduce_fn}{\code{list(fn)} the functions to be used to reduce the factors variable to one value}

\item{distance_fn}{\code{fn} (2 args) the function to compute the distance between two points}

\item{max_to_take}{\code{integer} the maximum number of simulations to read}
}
\value{
a list containing a data.table that contains the pairwise variogram statistics (distances, variance, covariance)
as well as some info about factors and response
}
\description{
compute the variogram
}
\examples{
\dontrun{
test <- variogram(path = "/gpfs/scratch/bsc32/bsc032637//out/", simulation_id = "2027582", response_var = "O3", factor_vars = c("TOL", "NO", "NO2", "solar_zenith_angle"), response_reduce_fn = max, factor_reduce_fn = list(data.table::first, data.table::first, data.table::first, mean))
}
}
